from ...models import get_currency_model, Currency
from django.core.management.base import BaseCommand


class Command(BaseCommand):
    def handle(self, *args, **kwargs):
        CurrencyModel: Currency = get_currency_model()

        predefined_currencies = [
            ('AED', '784', 'UAE Dirham', ['UNITED ARAB EMIRATES']),
            ('AFN', '971', 'Afghani', ['AFGHANISTAN']),
            ('ALL', '008', 'Lek', ['ALBANIA']),
            ('AMD', '051', 'Armenian Dram', ['ARMENIA']),
            ('ANG', '532', 'Netherlands Antillian Guilder', [
                'NETHERLANDS ANTILLES']),
            ('AOA', '973', 'Kwanza', ['ANGOLA']),
            ('ARS', '032', 'Argentine Peso', ['ARGENTINA']),
            ('AUD', '036', 'Australian Dollar', [
                'AUSTRALIA', 'CHRISTMAS ISLAND', 'COCOS (KEELING) ISLANDS',
                'HEARD ISLAND AND MCDONALD ISLANDS', 'KIRIBATI', 'NAURU',
                'NORFOLK ISLAND', 'TUVALU']),
            ('AWG', '533', 'Aruban Guilder', ['ARUBA']),
            ('AZN', '944', 'Azerbaijanian Manat', ['AZERBAIJAN']),
            ('BAM', '977', 'Convertible Marks', ['BOSNIA AND HERZEGOVINA']),
            ('BBD', '052', 'Barbados Dollar', ['BARBADOS']),
            ('BDT', '050', 'Taka', ['BANGLADESH']),
            ('BGN', '975', 'Bulgarian Lev', ['BULGARIA']),
            ('BHD', '048', 'Bahraini Dinar', ['BAHRAIN']),
            ('BIF', '108', 'Burundi Franc', ['BURUNDI']),
            ('BMD', '060',
                'Bermudian Dollar (customarily known as Bermuda Dollar)',
                ['BERMUDA']),
            ('BND', '096', 'Brunei Dollar', ['BRUNEI DARUSSALAM']),
            ('BOB', '068', 'Boliviano', ['BOLIVIA (PLURINATIONAL STATE OF)']),
            ('BOV', '984', 'Mvdol', ['BOLIVIA (PLURINATIONAL STATE OF)']),
            ('BRL', '986', 'Brazilian Real', ['BRAZIL']),
            ('BSD', '044', 'Bahamian Dollar', ['BAHAMAS']),
            ('BTN', '064', 'Bhutanese ngultrum', ['BHUTAN']),
            ('BWP', '072', 'Pula', ['BOTSWANA']),
            ('BYN', '933', 'Belarussian Ruble', ['BELARUS']),
            ('BYR', '974', 'Belarussian Ruble', ['BELARUS']),
            ('BZD', '084', 'Belize Dollar', ['BELIZE']),
            ('CAD', '124', 'Canadian Dollar', ['CANADA']),
            ('CDF', '976', 'Congolese franc',
                ['DEMOCRATIC REPUBLIC OF CONGO']),
            ('CHE', '947', 'WIR Euro', ['SWITZERLAND']),
            ('CHF', '756', 'Swiss Franc', ['LIECHTENSTEIN']),
            ('CHW', '948', 'WIR Franc', ['SWITZERLAND']),
            ('CLF', '990', 'Unidad de Fomento', ['CHILE']),
            ('CLP', '152', 'Chilean peso', ['CHILE']),
            ('CNY', '156', 'Yuan Renminbi', ['CHINA']),
            ('COP', '170', 'Colombian peso', ['COLOMBIA']),
            ('COU', '970', 'Unidad de Valor Real', ['COLOMBIA']),
            ('CRC', '188', 'Costa Rican Colon', ['COSTA RICA']),
            ('CUC', '931', 'Cuban convertible peso', ['CUBA']),
            ('CUP', '192', 'Cuban Peso', ['CUBA']),
            ('CVE', '132', 'Cape Verde Escudo', ['CAPE VERDE']),
            ('CZK', '203', 'Czech Koruna', ['CZECH REPUBLIC']),
            ('DJF', '262', 'Djibouti Franc', ['DJIBOUTI']),
            ('DKK', '208', 'Danish Krone', [
                'DENMARK', 'FAROE ISLANDS', 'GREENLAND']),
            ('DOP', '214', 'Dominican Peso', ['DOMINICAN REPUBLIC']),
            ('DZD', '012', 'Algerian Dinar', ['ALGERIA']),
            ('EGP', '818', 'Egyptian Pound', ['EGYPT']),
            ('ERN', '232', 'Nakfa', ['ERITREA']),
            ('ETB', '230', 'Ethiopian Birr', ['ETHIOPIA']),
            ('EUR', '978', 'Euro', [
                'AKROTIRI AND DHEKELIA', 'ANDORRA', 'AUSTRIA', 'BELGIUM',
                'CYPRUS', 'ESTONIA', 'FINLAND', 'FRANCE', 'GERMANY', 'GREECE',
                'GUADELOUPE', 'IRELAND', 'ITALY', 'KOSOVO', 'LATVIA',
                'LITHUANIA', 'LUXEMBOURG', 'MALTA', 'MARTINIQUE', 'MAYOTTE',
                'MONACO', 'MONTENEGRO', 'NETHERLANDS', 'PORTUGAL', 'RÉUNION',
                'SAINT BARTHÉLEMY', 'SAINT PIERRE AND MIQUELON', 'SAN MARINO',
                'SLOVAKIA', 'SLOVENIA', 'SPAIN', 'VATICAN CITY']),
            ('FJD', '242', 'Fiji Dollar', ['FIJI']),
            ('FKP', '238', 'Falkland Islands Pound', [
                'FALKLAND ISLANDS (MALVINAS)']),
            ('GBP', '826', 'Pound Sterling', ['UNITED KINGDOM']),
            ('GEL', '981', 'Lari', ['GEORGIA']),
            ('GHS', '936', 'Ghana Cedi', ['GHANA']),
            ('GIP', '292', 'Gibraltar Pound', ['GIBRALTAR']),
            ('GMD', '270', 'Dalasi', ['GAMBIA']),
            ('GNF', '324', 'Guinea Franc', ['GUINEA']),
            ('GTQ', '320', 'Quetzal', ['GUATEMALA']),
            ('GYD', '328', 'Guyana Dollar', ['GUYANA']),
            ('HKD', '344', 'Hong Kong Dollar', ['HONG KONG']),
            ('HNL', '340', 'Lempira', ['HONDURAS']),
            ('HRK', '191', 'Croatian Kuna', ['CROATIA']),
            ('HTG', '332', 'Haitian gourde', ['HAITI']),
            ('HUF', '348', 'Forint', ['HUNGARY']),
            ('IDR', '360', 'Rupiah', ['INDONESIA']),
            ('ILS', '376', 'New Israeli Sheqel', ['ISRAEL']),
            ('IMP', 'Nil', 'Isle of Man Pound', ['ISLE OF MAN']),
            ('INR', '356', 'Indian Rupee', ['INDIA']),
            ('IQD', '368', 'Iraqi Dinar', ['IRAQ']),
            ('IRR', '364', 'Iranian Rial', ['IRAN']),
            ('ISK', '352', 'Iceland Krona', ['ICELAND']),
            ('JMD', '388', 'Jamaican Dollar', ['JAMAICA']),
            ('JOD', '400', 'Jordanian Dinar', ['JORDAN']),
            ('JPY', '392', 'Yen', ['JAPAN']),
            ('KES', '404', 'Kenyan Shilling', ['KENYA']),
            ('KGS', '417', 'Som', ['KYRGYZSTAN']),
            ('KHR', '116', 'Riel', ['CAMBODIA']),
            ('KMF', '174', 'Comoro Franc', ['COMOROS']),
            ('KPW', '408', 'North Korean Won', ['KOREA']),
            ('KRW', '410', 'Won', ['KOREA']),
            ('KWD', '414', 'Kuwaiti Dinar', ['KUWAIT']),
            ('KYD', '136', 'Cayman Islands Dollar', ['CAYMAN ISLANDS']),
            ('KZT', '398', 'Tenge', ['KAZAKHSTAN']),
            ('LAK', '418', 'Kip', ['LAO PEOPLES DEMOCRATIC REPUBLIC']),
            ('LBP', '422', 'Lebanese Pound', ['LEBANON']),
            ('LKR', '144', 'Sri Lanka Rupee', ['SRI LANKA']),
            ('LRD', '430', 'Liberian Dollar', ['LIBERIA']),
            ('LSL', '426', 'Lesotho loti', ['LESOTHO']),
            ('LTL', '440', 'Lithuanian Litas', ['LITHUANIA']),
            ('LVL', '428', 'Latvian Lats', ['LATVIA']),
            ('LYD', '434', 'Libyan Dinar', ['LIBYAN ARAB JAMAHIRIYA']),
            ('MAD', '504', 'Moroccan Dirham', ['MOROCCO', 'WESTERN SAHARA']),
            ('MDL', '498', 'Moldovan Leu', ['MOLDOVA']),
            ('MGA', '969', 'Malagasy Ariary', ['MADAGASCAR']),
            ('MKD', '807', 'Denar', ['MACEDONIA']),
            ('MMK', '104', 'Kyat', ['MYANMAR']),
            ('MNT', '496', 'Tugrik', ['MONGOLIA']),
            ('MOP', '446', 'Pataca', ['MACAO']),
            ('MRO', '478', 'Ouguiya', ['MAURITANIA']),
            ('MUR', '480', 'Mauritius Rupee', ['MAURITIUS']),
            ('MVR', '462', 'Rufiyaa', ['MALDIVES']),
            ('MWK', '454', 'Malawian Kwacha', ['MALAWI']),
            ('MXN', '484', 'Mexican peso', ['MEXICO']),
            ('MXV', '979', 'Mexican Unidad de Inversion (UDI)', ['MEXICO']),
            ('MYR', '458', 'Malaysian Ringgit', ['MALAYSIA']),
            ('MZN', '943', 'Metical', ['MOZAMBIQUE']),
            ('NAD', '516', 'Namibian Dollar', ['NAMIBIA']),
            ('NGN', '566', 'Naira', ['NIGERIA']),
            ('NIO', '558', 'Cordoba Oro', ['NICARAGUA']),
            ('NOK', '578', 'Norwegian Krone', [
                'BOUVET ISLAND', 'NORWAY', 'SVALBARD AND JAN MAYEN']),
            ('NPR', '524', 'Nepalese Rupee', ['NEPAL']),
            ('NZD', '554', 'New Zealand Dollar', [
                'COOK ISLANDS', 'NEW ZEALAND', 'NIUE', 'PITCAIRN', 'TOKELAU']),
            ('OMR', '512', 'Rial Omani', ['OMAN']),
            ('PAB', '590', 'Balboa', ['PANAMA']),
            ('PEN', '604', 'Nuevo Sol', ['PERU']),
            ('PGK', '598', 'Kina', ['PAPUA NEW GUINEA']),
            ('PHP', '608', 'Philippine Peso', ['PHILIPPINES']),
            ('PKR', '586', 'Pakistan Rupee', ['PAKISTAN']),
            ('PLN', '985', 'Zloty', ['POLAND']),
            ('PYG', '600', 'Guarani', ['PARAGUAY']),
            ('QAR', '634', 'Qatari Rial', ['QATAR']),
            ('RON', '946', 'New Leu', ['ROMANIA']),
            ('RSD', '941', 'Serbian Dinar', ['SERBIA']),
            ('RUB', '643', 'Russian Ruble', ['RUSSIAN FEDERATION']),
            ('RWF', '646', 'Rwanda Franc', ['RWANDA']),
            ('SAR', '682', 'Saudi Riyal', ['SAUDI ARABIA']),
            ('SBD', '090', 'Solomon Islands Dollar', ['SOLOMON ISLANDS']),
            ('SCR', '690', 'Seychelles Rupee', ['SEYCHELLES']),
            ('SDG', '938', 'Sudanese Pound', ['SUDAN']),
            ('SEK', '752', 'Swedish Krona', ['SWEDEN']),
            ('SGD', '702', 'Singapore Dollar', ['SINGAPORE']),
            ('SHP', '654', 'Saint Helena Pound', ['SAINT HELENA']),
            ('SLL', '694', 'Leone', ['SIERRA LEONE']),
            ('SOS', '706', 'Somali Shilling', ['SOMALIA']),
            ('SRD', '968', 'Surinam Dollar', ['SURINAME']),
            ('SSP', '728', 'South Sudanese Pound', ['SOUTH SUDAN']),
            ('STD', '678', 'Dobra', ['SAO TOME AND PRINCIPE']),
            ('SVC', '222', 'El Salvador Colon', ['EL SALVADOR']),
            ('SYP', '760', 'Syrian Pound', ['SYRIAN ARAB REPUBLIC']),
            ('SZL', '748', 'Lilangeni', ['SWAZILAND']),
            ('THB', '764', 'Baht', ['THAILAND']),
            ('TJS', '972', 'Somoni', ['TAJIKISTAN']),
            ('TMM', '795', 'Manat', ['TURKMENISTAN']),
            ('TMT', '934', 'Turkmenistan New Manat', ['TURKMENISTAN']),
            ('TND', '788', 'Tunisian Dinar', ['TUNISIA']),
            ('TOP', '776', 'Paanga', ['TONGA']),
            ('TRY', '949', 'Turkish Lira', ['TURKEY']),
            ('TTD', '780', 'Trinidad and Tobago Dollar',
                ['TRINIDAD AND TOBAGO']),
            ('TVD', 'Nil', 'Tuvalu dollar', ['TUVALU']),
            ('TWD', '901', 'New Taiwan Dollar', ['TAIWAN']),
            ('TZS', '834', 'Tanzanian Shilling', ['TANZANIA']),
            ('UAH', '980', 'Hryvnia', ['UKRAINE']),
            ('UGX', '800', 'Uganda Shilling', ['UGANDA']),
            ('USD', '840', 'US Dollar', [
                'AMERICAN SAMOA', 'BRITISH INDIAN OCEAN TERRITORY',
                'ECUADOR', 'GUAM', 'MARSHALL ISLANDS', 'MICRONESIA',
                'NORTHERN MARIANA ISLANDS', 'PALAU', 'PUERTO RICO',
                'TIMOR-LESTE', 'TURKS AND CAICOS ISLANDS', 'UNITED STATES',
                'UNITED STATES MINOR OUTLYING ISLANDS',
                'VIRGIN ISLANDS (BRITISH)', 'VIRGIN ISLANDS (U.S.)']),
            ('USN', '997', 'US Dollar (Next day)',
                ['UNITED STATES OF AMERICA (THE)']),
            ('UYI', '940', 'Uruguay Peso en Unidades Indexadas (URUIURUI)',
                ['URUGUAY']),
            ('UYU', '858', 'Uruguayan peso', ['URUGUAY']),
            ('UZS', '860', 'Uzbekistan Sum', ['UZBEKISTAN']),
            ('VEF', '937', 'Bolivar Fuerte', ['VENEZUELA']),
            ('VND', '704', 'Dong', ['VIET NAM']),
            ('VUV', '548', 'Vatu', ['VANUATU']),
            ('WST', '882', 'Tala', ['SAMOA']),
            ('XAF', '950', 'CFA franc BEAC', [
                'CAMEROON', 'CENTRAL AFRICAN REPUBLIC',
                'REPUBLIC OF THE CONGO', 'CHAD',
                'EQUATORIAL GUINEA', 'GABON']),
            ('XAG', '961', 'Silver', []),
            ('XAU', '959', 'Gold', []),
            ('XBA', '955',
                'Bond Markets Units European Composite Unit (EURCO)', []),
            ('XBB', '956', 'European Monetary Unit (E.M.U.-6)', []),
            ('XBC', '957', 'European Unit of Account 9(E.U.A.-9)', []),
            ('XBD', '958', 'European Unit of Account 17(E.U.A.-17)', []),
            ('XCD', '951', 'East Caribbean Dollar', [
                'ANGUILLA', 'ANTIGUA AND BARBUDA', 'DOMINICA', 'GRENADA',
                'MONTSERRAT', 'SAINT KITTS AND NEVIS', 'SAINT LUCIA',
                'SAINT VINCENT AND THE GRENADINES']),
            ('XDR', '960', 'SDR', ['INTERNATIONAL MONETARY FUND (I.M.F)']),
            ('XFO', 'Nil', 'Gold-Franc', []),
            ('XFU', 'Nil', 'UIC-Franc', []),
            ('XOF', '952', 'CFA Franc BCEAO', [
                'BENIN', 'BURKINA FASO', 'COTE D\'IVOIRE', 'GUINEA-BISSAU',
                'MALI', 'NIGER', 'SENEGAL', 'TOGO']),
            ('XPD', '964', 'Palladium', []),
            ('XPF', '953', 'CFP Franc', [
                'FRENCH POLYNESIA', 'NEW CALEDONIA', 'WALLIS AND FUTUNA']),
            ('XPT', '962', 'Platinum', []),
            ('XSU', '994', 'Sucre', [
                'SISTEMA UNITARIO DE COMPENSACION REGIONAL DE PAGOS "SUCRE"']),
            ('XTS', '963',
                'Codes specifically reserved for testing purposes', []),
            ('XUA', '965', 'ADB Unit of Account', [
                'MEMBER COUNTRIES OF THE AFRICAN DEVELOPMENT BANK GROUP']),
            ('XXX', '999',
                'The codes assigned for transactions where '
                'no currency is involved', ['ZZ07_No_Currency']),
            ('YER', '886', 'Yemeni Rial', ['YEMEN']),
            ('ZAR', '710', 'Rand', ['SOUTH AFRICA']),
            ('ZMK', '894', 'Zambian Kwacha', []),
            ('ZMW', '967', 'Zambian Kwacha', ['ZAMBIA']),
            ('ZWD', '716', 'Zimbabwe Dollar A/06', ['ZIMBABWE']),
            ('ZWL', '932', 'Zimbabwe dollar A/09', ['ZIMBABWE']),
            ('ZWN', '942', 'Zimbabwe dollar A/08', ['ZIMBABWE']),
        ]

        bulk_list = []
        for (code, numeric, name, countries) in predefined_currencies:
            bulk_list.append(
                CurrencyModel(
                    code=code, name=name,
                    numeric=numeric, countries=countries)
            )
        currencies = CurrencyModel.objects.bulk_create(bulk_list)
        print(f"{len(currencies)} currencies Inserted!")
